@@ -823,36 +823,6 @@ void renamepage(short pagenumber)
       Tcl_Eval(xcinterp, pname);
       free(pname);
    }
-
-   /* The GUI has been taken care of, but the page itself might not exist */
-   if (!thisinst) return;
-
-   /* If the page had a master but now has a different	*/
-   /* name, disconnect the schematics.			*/
-
-   if (thisinst->thisobject->schemtype == SECONDARY) {
-      if (strcmp(thisinst->thisobject->name, thisinst->thisobject->symschem->name)) {
-	 thisinst->thisobject->symschem = NULL;
-	 thisinst->thisobject->schemtype = PRIMARY;
-      }
-      Wprintf("Page disconnected from master schematic.");
-   }
-
-   /* Conversely, if the page has the same name as another page, the	*/
-   /* schematics are considered connected.				*/
-
-   for (page = 0; page < xobjs.pages; page++) {
-      objinstptr pageinst;
-      if (page == pagenumber) continue;
-      pageinst = xobjs.pagelist[page]->pageinst;
-      if (pageinst && !strcmp(pageinst->thisobject->name,
-		thisinst->thisobject->name)) {
-	 thisinst->thisobject->symschem = pageinst->thisobject;
-	 thisinst->thisobject->schemtype = SECONDARY;
-         Wprintf("Page connected to master schematic.");
-	 break;
-      }
-   }
 }
 
 /*--------------------------------------------------------------*/
